@@ -36,26 +36,28 @@ load an atlas image, which will be one of the following atlas-specific
    :nosignatures:
 
    LabelAtlas
+   StatisticAtlas
    ProbabilisticAtlas
 """
 
 
 from __future__ import division
 
-import xml.etree.ElementTree              as et
-import os.path                            as op
-import                                       glob
-import                                       bisect
-import                                       logging
+import xml.etree.ElementTree    as et
+import os.path                  as op
+import                             glob
+import                             bisect
+import                             logging
 
-import numpy                              as np
+import numpy                    as np
 
-import fsl.data.image                     as fslimage
-import fsl.data.constants                 as constants
-from   fsl.utils.platform import platform as platform
-import fsl.utils.transform                as transform
-import fsl.utils.notifier                 as notifier
-import fsl.utils.settings                 as fslsettings
+import fsl.data.image           as fslimage
+import fsl.data.constants       as constants
+from   fsl.utils.platform import   platform
+import fsl.utils.image.resample as resample
+import fsl.transform.affine     as affine
+import fsl.utils.notifier       as notifier
+import fsl.utils.settings       as fslsettings
 
 
 log = logging.getLogger(__name__)
@@ -134,7 +136,7 @@ class AtlasRegistry(notifier.Notifier):
 
                 try:
                     self.addAtlas(atlasPath, atlasID, save=False)
-                except:
+                except Exception:
                     log.warning('Failed to load atlas '
                                 'specification {}'.format(atlasPath),
                                 exc_info=True)
@@ -167,7 +169,7 @@ class AtlasRegistry(notifier.Notifier):
         raise KeyError('Unknown atlas ID: {}'.format(atlasID))
 
 
-    def loadAtlas(self, atlasID, loadSummary=False, resolution=None):
+    def loadAtlas(self, atlasID, loadSummary=False, resolution=None, **kwargs):
         """Loads and returns an :class:`Atlas` instance for the atlas
         with the given  ``atlasID``.
 
@@ -189,10 +191,10 @@ class AtlasRegistry(notifier.Notifier):
         if atlasDesc.atlasType == 'label':
             loadSummary = True
 
-        if loadSummary: atlas = LabelAtlas(        atlasDesc, resolution)
-        else:           atlas = ProbabilisticAtlas(atlasDesc, resolution)
+        if loadSummary: atype = LabelAtlas
+        else:           atype = ProbabilisticAtlas
 
-        return atlas
+        return atype(atlasDesc, resolution, **kwargs)
 
 
     def addAtlas(self, filename, atlasID=None, save=True):
@@ -244,6 +246,8 @@ class AtlasRegistry(notifier.Notifier):
         ``AtlasRegistry``.
         """
 
+        remove = None
+
         for i, desc in enumerate(self.__atlasDescs):
             if desc.atlasID == atlasID:
 
@@ -252,11 +256,13 @@ class AtlasRegistry(notifier.Notifier):
                     desc.specPath))
 
                 self.__atlasDescs.pop(i)
+                remove = desc
                 break
 
         self.__saveKnownAtlases()
 
-        self.notify(topic='remove', value=desc)
+        if remove is not None:
+            self.notify(topic='remove', value=remove)
 
 
     def __getKnownAtlases(self):
@@ -285,7 +291,7 @@ class AtlasRegistry(notifier.Notifier):
 
             return names, paths
 
-        except:
+        except Exception:
             return [], []
 
 
@@ -314,17 +320,18 @@ class AtlasLabel(object):
 
     An ``AtlasLabel`` instance contains the following attributes:
 
-    ========= ==============================================================
+    ========= ================================================================
     ``name``  Region name
-    ``index`` For probabilistic atlases, the volume index into the 4D atlas
-              image that corresponds to this region. For label atlases, the
-              value of voxels that are in this region. For summary images of
-              probabilistic atlases, add 1 to this value to get the
-              corresponding voxel values.
+    ``index`` The index of this label into the list of all labels in the
+              ``AtlasDescription`` that owns it. For statistic/probabilistic
+              atlases, this is also the index into the 4D atlas image of the
+              volume that corresponds to this region.
+    ``value`` For label atlases and summary images, the value of voxels that
+              are in this region.
     ``x``     X coordinate of the region in world space
     ``y``     Y coordinate of the region in world space
     ``z``     Z coordinate of the region in world space
-    ========= ==============================================================
+    ========= ================================================================
 
     .. note:: The ``x``, ``y`` and ``z`` label coordinates are pre-calculated
               centre-of-gravity coordinates, as listed in the atlas xml file.
@@ -333,9 +340,10 @@ class AtlasLabel(object):
               XML file (typically MNI152 space).
     """
 
-    def __init__(self, name, index, x, y, z):
+    def __init__(self, name, index, value, x, y, z):
         self.name  = name
         self.index = index
+        self.value = value
         self.x     = x
         self.y     = y
         self.z     = z
@@ -359,6 +367,15 @@ class AtlasLabel(object):
         """
         return self.index < other.index
 
+    def __repr__(self):
+        """
+        Represents AtlasLabel as string
+        """
+        return '{}({}, index={}, value={})'.format(
+                self.__class__.__name__, self.name,
+                self.index, self.value,
+        )
+
 
 class AtlasDescription(object):
     """An ``AtlasDescription`` instance parses and stores the information
@@ -370,8 +387,13 @@ class AtlasDescription(object):
 
        <atlas>
          <header>
-           <name></name>        # Atlas name
-           <type></type>        # 'Probabilistic' or 'Label'
+           <name></name>           # Atlas name
+           <type></type>           # 'Statistic', 'Probabilistic' or 'Label'
+           <statistic></statistic> # Optional. Type of statistic
+           <units></units>         # Optional. Units of measurement
+           <precision></precision> # Optional. Decimal precision to report
+           <upper></upper>         # Optional. Upper threshold
+           <lower></lower>         # Optional. Lower threshold
            <images>
             <imagefile>
             </imagefile>        # If type is Probabilistic, path
@@ -383,8 +405,11 @@ class AtlasDescription(object):
                                 # as relative to the location of this
                                 # XML file.
 
-            <summaryimagefile>  # Path to 3D summary file, with each
-            </summaryimagefile> # region having value (index + 1)
+            <summaryimagefile>  # Path to 3D label summary file,
+            </summaryimagefile> # Every <image> must be accompanied
+                                # by a <summaryimage> - for label
+                                # atlases, they will typically refer
+                                # to the same image file.
 
            </images>
            ...                  # More images - generally both
@@ -393,9 +418,13 @@ class AtlasDescription(object):
          </header>
         <data>
 
-         # index - For probabilistic atlases, index of corresponding volume in
-         #         4D image file. For label images, the value of voxels which
-         #         are in the corresponding region.
+         # index - For statistic/probabilistic atlases, index of corresponding
+         #         volume in 4D image file. For label images, the value of
+         #         voxels which are in the corresponding region. For
+         #         statistic/probabilistic atlases, it is assumed that the
+         #         value for each region in the summary image(s) are equal to
+         #         ``index + 1``.
+         #
          #
          # x    |
          # y    |- XYZ *voxel* coordinates into the first image of the <images>
@@ -430,7 +459,18 @@ class AtlasDescription(object):
 
     ``specPath``      Path to the atlas XML specification file.
 
-    ``atlasType``     Atlas type - either *probabilistic* or *label*.
+    ``atlasType``     Atlas type - either *statistic*, *probabilistic* or
+                      *label*.
+
+    ``statistic``     Type of statistic, for statistic atlases.
+
+    ``units``         Unit of measurement, for statistic atlases.
+
+    ``precision``     Reporting precision, for statistic atlases.
+
+    ``upper``         Upper threshold, for statistic atlases.
+
+    ``lower``         Lower threshold, for statistic atlases.
 
     ``images``        A list of images available for this atlas - usually
                       :math:`1mm^3` and :math:`2mm^3` images are present.
@@ -471,13 +511,36 @@ class AtlasDescription(object):
 
         self.atlasID   = atlasID
         self.specPath  = op.abspath(filename)
-        self.name      = header.find('name').text
-        self.atlasType = header.find('type').text.lower()
+        self.name      = header.find('name').text.strip()
+        self.atlasType = header.find('type').text.strip().lower()
 
         # Spelling error in some of the atlas.xml files.
         if self.atlasType == 'probabalistic':
             self.atlasType = 'probabilistic'
 
+        if self.atlasType == 'statistic':
+
+            fields = ['statistic', 'units', 'lower', 'upper', 'precision']
+            values = {}
+
+            for field in fields:
+                elem = header.find(field)
+                if elem is not None and elem.text is not None:
+                    values[field] = elem.text.strip()
+
+            self.statistic =       values.get('statistic', '')
+            self.units     =       values.get('units',     '')
+            self.lower     = float(values.get('lower',     0))
+            self.upper     = float(values.get('upper',     100))
+            self.precision = int(  values.get('precision', 2))
+
+        elif self.atlasType == 'probabilistic':
+            self.statistic = ''
+            self.units     = '%'
+            self.lower     = 5
+            self.upper     = 100
+            self.precision = 0
+
         images             = header.findall('images')
         self.images        = []
         self.summaryImages = []
@@ -487,13 +550,15 @@ class AtlasDescription(object):
         atlasDir = op.dirname(self.specPath)
 
         for image in images:
-            imagefile        = image.find('imagefile')       .text
-            summaryimagefile = image.find('summaryimagefile').text
+
+            # Every image must also have a summary image
+            imagefile        = image.find('imagefile')       .text.strip()
+            summaryimagefile = image.find('summaryimagefile').text.strip()
 
             # Assuming that the path
             # names begin with a slash
-            imagefile        = op.join(atlasDir, '.' + imagefile)
-            summaryimagefile = op.join(atlasDir, '.' + summaryimagefile)
+            imagefile        = op.normpath(atlasDir + imagefile)
+            summaryimagefile = op.normpath(atlasDir + summaryimagefile)
 
             i = fslimage.Image(imagefile, loadData=False, calcRange=False)
 
@@ -505,6 +570,11 @@ class AtlasDescription(object):
         labels      = data.findall('label')
         self.labels = []
 
+        # Refs to AtlasLabel objects
+        # indexed by their value.
+        # Used by the find method.
+        self.__labelsByValue = {}
+
         # The xyz coordinates for each label are in terms
         # of the voxel space of the first images element
         # in the header. For convenience, we're going to
@@ -514,27 +584,78 @@ class AtlasDescription(object):
 
         for i, label in enumerate(labels):
 
-            name  = label.text
+            name  = label.text.strip()
             index = int(  label.attrib['index'])
             x     = float(label.attrib['x'])
             y     = float(label.attrib['y'])
             z     = float(label.attrib['z'])
-            al    = AtlasLabel(name, index, x, y, z)
 
+            # For label images, the index field
+            # contains the region value
+            if self.atlasType == 'label':
+                value = index
+                index = i
+
+            # For probablistic images, the index
+            # field specifies the volume in the
+            # 4D atlas corresponding to the region.
+            # It is assumed that the summary value
+            # for each region is index + 1
+            else:
+                value = index + 1
+
+            al        = AtlasLabel(name, index, value, x, y, z)
             coords[i] = (x, y, z)
 
             self.labels.append(al)
+            self.__labelsByValue[value] = al
 
         # Load the appropriate transformation matrix
         # and transform all those voxel coordinates
         # into world coordinates
-        coords = transform.transform(coords, self.xforms[0])
+        coords = affine.transform(coords, self.xforms[0])
 
         # Update the coordinates
         # in our label objects
         for i, label in enumerate(self.labels):
             label.x, label.y, label.z = coords[i]
 
+        # Make sure the labels are sorted by index
+        self.labels = list(sorted(self.labels))
+
+
+    def find(self, index=None, value=None, name=None):
+        """Find an :class:`.AtlasLabel` either by ``index``, or by ``value``.
+
+        Exactly one of ``index``, ``value``, or ``name`` may be specified - a
+        ``ValueError`` is raised otherwise. If an invalid ``index``, ``name``, or
+        ``value`` is specified, an ``IndexError`` or ``KeyError`` will be
+        raised.
+
+        .. note:: A 4D ``ProbabilisticAtlas`` may have more volumes than
+                  labels, and a 3D ``LabelAtlas`` may have more values
+                  than labels.
+        """
+        if ((index is not None) + (value is not None) + (name is not None)) != 1:
+            raise ValueError('Only one of index, value, or name may be specified')
+        if index is not None:   return self.labels[         index]
+        elif value is not None: return self.__labelsByValue[int(value)]
+        else:
+            matches = [l for l in self.labels if l.name == name]
+            if len(matches) == 0:
+                # look for partial matches only if there are no full matches
+                matches = [l for l in self.labels if l.name[:len(name)] == name]
+            if len(matches) == 0:
+                raise IndexError('No match for {} found in labels {}'.format(
+                    name, tuple(l.name for l in self.labels)
+                ))
+            elif len(matches) > 1:
+                raise IndexError('Multiple matches for {} found in labels {}'.format(
+                    name, tuple(l.name for l in self.labels)
+                ))
+            return matches[0]
+
+
 
     def __eq__(self, other):
         """Compares the ``atlasID`` of this ``AtlasDescription`` with another.
@@ -554,6 +675,12 @@ class AtlasDescription(object):
         """
         return self.name.lower() < other.name.lower()
 
+    def __repr__(self, ):
+        """
+        String representation of AtlasDescription
+        """
+        return '{}({})'.format(self.__class__.__name__, self.atlasID)
+
 
 class Atlas(fslimage.Image):
     """This is the base class for the :class:`LabelAtlas` and
@@ -562,7 +689,11 @@ class Atlas(fslimage.Image):
     """
 
 
-    def __init__(self, atlasDesc, resolution=None, isLabel=False):
+    def __init__(self,
+                 atlasDesc,
+                 resolution=None,
+                 isLabel=False,
+                 **kwargs):
         """Initialise an ``Atlas``.
 
         :arg atlasDesc:  The :class:`AtlasDescription` instance which
@@ -571,7 +702,9 @@ class Atlas(fslimage.Image):
         :arg resolution: Desired isotropic resolution in millimetres.
 
         :arg isLabel:    Pass in ``True`` for label atlases, ``False`` for
-                         probabilistic atlases.
+                         statistic/probabilistic atlases.
+
+        All other arguments are passed to :meth:`.Image.__init__`.
         """
 
         # Get the index of the atlas with the
@@ -594,7 +727,7 @@ class Atlas(fslimage.Image):
         if isLabel: imageFile = atlasDesc.summaryImages[imageIdx]
         else:       imageFile = atlasDesc.images[       imageIdx]
 
-        fslimage.Image.__init__(self, imageFile)
+        fslimage.Image.__init__(self, imageFile, **kwargs)
 
         # Even though all the FSL atlases
         # are in MNI152 space, not all of
@@ -605,6 +738,54 @@ class Atlas(fslimage.Image):
         self.desc = atlasDesc
 
 
+    def find(self, *args, **kwargs):
+        """Find an ``AtlasLabel`` - see the :meth:`AtlasDescription.find`
+        method.
+        """
+        return self.desc.find(*args, **kwargs)
+
+
+    def prepareMask(self, mask):
+        """Makes sure that the given mask has the same resolution as this
+        atlas, so it can be used for querying. Used by the
+        :meth:`.LabelAtlas.maskLabels` and
+        :meth:`.StatisticAtlas.maskValues` methods.
+
+        :arg mask: A :class:`.Image`
+
+        :returns:  A ``numpy`` array containing the resampled mask data.
+
+        :raises:   A :exc:`MaskError` if the mask is not in the same space as
+                   this atlas, or does not have three dimensions.
+        """
+
+        # Make sure that the mask has the same
+        # number of voxels as the atlas image.
+        # Use nearest neighbour interpolation
+        # for resampling, as it is most likely
+        # that the mask is binary.
+        try:
+            mask, xform = resample.resample(
+                mask, self.shape[:3], dtype=np.float32, order=0)
+
+        except ValueError:
+            raise MaskError('Mask has wrong number of dimensions')
+
+        # TODO allow non-aligned mask - as long as it overlaps
+        #      in world coordinates, it should be allowed
+        if not fslimage.Image(mask, xform=xform).sameSpace(self):
+            raise MaskError('Mask is not in the same space as atlas')
+
+        return mask
+
+
+class MaskError(Exception):
+    """Exception raised by the :meth:`LabelAtlas.maskLabel` and
+    :meth:`StatisticAtlas.maskValues` when a mask is provided which
+    does not match the atlas space.
+    """
+
+
 class LabelAtlas(Atlas):
     """A 3D atlas which contains integer labels for each region.
 
@@ -612,7 +793,7 @@ class LabelAtlas(Atlas):
     makes looking up the label at a location easy.
     """
 
-    def __init__(self, atlasDesc, resolution=None):
+    def __init__(self, atlasDesc, resolution=None, **kwargs):
         """Create a ``LabelAtlas`` instance.
 
         :arg atlasDesc:  The :class:`AtlasDescription` instance describing
@@ -620,7 +801,7 @@ class LabelAtlas(Atlas):
 
         :arg resolution: Desired isotropic resolution in millimetres.
         """
-        Atlas.__init__(self, atlasDesc, resolution, True)
+        Atlas.__init__(self, atlasDesc, resolution, True, **kwargs)
 
 
     def label(self, location, *args, **kwargs):
@@ -662,10 +843,13 @@ class LabelAtlas(Atlas):
 
         :returns:   The label at the given coordinates, or ``None`` if the
                     coordinates are out of bounds.
+
+        .. note:: Use the :meth:`find` method to retrieve the ``AtlasLabel``
+                  associated with each returned value.
         """
 
         if not voxel:
-            loc = transform.transform([loc], self.worldToVoxMat)[0]
+            loc = affine.transform([loc], self.worldToVoxMat)[0]
             loc = [int(v) for v in loc.round()]
 
         if loc[0] <  0             or \
@@ -676,13 +860,7 @@ class LabelAtlas(Atlas):
            loc[2] >= self.shape[2]:
             return None
 
-        val = self[loc[0], loc[1], loc[2]]
-
-        if self.desc.atlasType == 'label':
-            return val
-
-        elif self.desc.atlasType == 'probabilistic':
-            return val - 1
+        return self[loc[0], loc[1], loc[2]]
 
 
     def maskLabel(self, mask):
@@ -692,101 +870,157 @@ class LabelAtlas(Atlas):
         :arg mask: A 3D :class:`.Image`` which is interpreted as a weighted
                    mask. If the ``mask`` shape does not match that of this
                    ``LabelAtlas``, it is resampled using
-                   :meth:`.Image.resample`, with linear interpolation.
+                   :meth:`.Image.resample`, with nearest-neighbour
+                   interpolation.
 
         :returns:  A tuple containing:
 
-                     - A sequence of all labels which are present in the mask
+                     - A sequence of all values  which are present in the mask
                      - A sequence containing the proportion, within the mask,
-                       of each present label. The proportions are returned as
+                       of each present value. The proportions are returned as
                        values between 0 and 100.
 
+        .. note:: Use the :meth:`find` method to retrieve the ``AtlasLabel``
+                  associated with each returned value.
         """
 
-        # Make sure that the mask has the same
-        # number of voxels as the atlas image.
-        # Use nearest neighbour interpolation
-        # for resampling, as it is most likely
-        # that the mask is binary.
-        mask     = mask.resample(self.shape[:3], dtype=np.float32, order=0)[0]
-        boolmask = mask > 0
-
-        fslimage.Image(mask, xform=self.voxToWorldMat).save('blag.nii.gz')
-
-        # Extract the labels that are in
+        # Extract the values that are in
         # the mask, and their corresponding
         # mask weights
+        mask      = self.prepareMask(mask)
+        boolmask  = mask > 0
         vals      = self[boolmask]
         weights   = mask[boolmask]
         weightsum = weights.sum()
-        labels    = np.unique(vals)
+        gotValues = np.unique(vals)
+        values    = []
         props     = []
 
-        for label in labels:
+        # Only consider labels that
+        # this atlas is aware of
+        for label in self.desc.labels:
+            if label.value in gotValues:
 
-            # Figure out the number of all voxels
-            # in the mask with this label, weighted
-            # by the mask.
-            prop = weights[vals == label].sum()
+                # Figure out the number of all voxels
+                # in the mask with this value, weighted
+                # by the mask.
+                prop = weights[vals == label.value].sum()
 
-            # Normalise it to be a proportion
-            # of all voxels in the mask. We
-            # multiply by 100 because the FSL
-            # probabilistic atlases store their
-            # probabilities as percentages.
-            props.append(100 * prop / weightsum)
+                # Normalise it to be a proportion
+                # of all voxels in the mask. We
+                # multiply by 100 because the FSL
+                # probabilistic atlases store their
+                # probabilities as percentages.
+                values.append(label.value)
+                props .append(100 * prop / weightsum)
 
-        return labels, props
+        return values, props
 
 
-class ProbabilisticAtlas(Atlas):
-    """A 4D atlas which contains one volume for each region.
+    def get(self, label=None, index=None, value=None, name=None, binary=True):
+        """Returns the binary image for the given label.
 
-    The ``ProbabilisticAtlas`` provides the :meth`proportions` method,
-    which makes looking up region probabilities easy.
+        Only one of the arguments should be used to define the label
+
+        :arg label:  :class:`AtlasLabel` contained within this atlas
+        :arg index:  index of the label
+        :arg value:  value of the label
+        :arg name:   string of the label
+        :arg binary: If ``True`` (the default), the image will contain 1s in
+                     the label region. Otherwise the image will contain the
+                     label value.
+        :return:     :class:`.Image` with the mask
+        """
+        if ((label is not None) + (index is not None) +
+            (value is not None) + (name is not None)) != 1:
+            raise ValueError('Only one of label, index, value, or name may be specified')
+        if label is None:
+            label = self.find(index=index, name=name, value=value)
+        elif label not in self.desc.labels:
+            raise ValueError("Unknown label provided")
+
+        arr = (self.data == label.value).astype(np.int32)
+
+        if not binary:
+            arr[arr > 0] = label.value
+
+        return fslimage.Image(arr, name=label.name, header=self.header)
+
+
+class StatisticAtlas(Atlas):
+    """A ``StatisticAtlas`` is a 4D image which contains one volume for
+    each region in the atlas; each volume contains some statistic value
+    for the corresponding region.
+
+    The :class:`ProbabilisticAtlas` is a specialisation of the
+    ``StatisticAtlas``
     """
 
-    def __init__(self, atlasDesc, resolution=None):
-        """Create a ``ProbabilisticAtlas`` instance.
+
+    def __init__(self, atlasDesc, resolution=None, **kwargs):
+        """Create a ``StatisticAtlas`` instance.
 
         :arg atlasDesc:  The :class:`AtlasDescription` instance describing
                          the atlas.
 
         :arg resolution: Desired isotropic resolution in millimetres.
         """
-        Atlas.__init__(self, atlasDesc, resolution, False)
+        Atlas.__init__(self, atlasDesc, resolution, False, **kwargs)
 
 
-    def proportions(self, location, *args, **kwargs):
-        """Looks up and returns the proportions of of all regions at the given
+    def get(self, label=None, index=None, value=None, name=None):
+        """Returns the statistic image at the given label.
+
+        Only one of the arguments should be used to define the label
+
+        :arg label: :class:`AtlasLabel` contained within this atlas
+        :arg index: index of the label
+        :arg value: value of the label
+        :arg name:  string of the label
+        :return:    :class:`.Image` with the statistic values for the
+                    specified label.
+        """
+        if ((label is not None) + (index is not None) +
+            (value is not None) + (name is not None)) != 1:
+            raise ValueError('Only one of label, index, value, or name may be specified')
+        if label is None:
+            label = self.find(index=index, value=value, name=name)
+        elif label not in self.desc.labels:
+            raise ValueError("Unknown label provided")
+        arr = self[..., label.index]
+        return fslimage.Image(arr, name=label.name, header=self.header)
+
+
+    def values(self, location, *args, **kwargs):
+        """Looks up and returns the values of of all regions at the given
         location.
 
         :arg location: Can be one of the following:
 
                         - A sequence of three values, interpreted as atlas
-                          coordinates. In this case, :meth:`coordProportions`
+                          coordinates. In this case, :meth:`coordValues`
                           is called.
 
                         - An :class:`.Image` which is interpreted as a
-                          weighted mask. In this case, :meth:`maskProportions`
+                          weighted mask. In this case, :meth:`maskValues`
                           is called.
 
-        All other arguments are passed through to the :meth:`coordProportions`
-        or :meth:`maskProportions` methods.
+        All other arguments are passed through to the :meth:`coordValues`
+        or :meth:`maskValues` methods.
 
 
-        :returns: The return value of either :meth:`coordProportions` or
-                  :meth:`maskProportions`.
+        :returns: The return value of either :meth:`coordValues` or
+                  :meth:`maskValues`.
         """
 
         if isinstance(location, fslimage.Image):
-            return self.maskProportions(location, *args, **kwargs)
+            return self.maskValues(location, *args, **kwargs)
         else:
-            return self.coordProportions(location, *args, **kwargs)
+            return self.coordValues(location, *args, **kwargs)
 
 
-    def coordProportions(self, loc, voxel=False):
-        """Looks up the region probabilities for the given location.
+    def coordValues(self, loc, voxel=False):
+        """Looks up the region values for the given location.
 
         :arg loc:   A sequence of three values, interpreted as atlas
                     world or voxel coordinates.
@@ -794,14 +1028,12 @@ class ProbabilisticAtlas(Atlas):
         :arg voxel: Defaults to ``False``. If ``True``, the ``loc``
                     argument is interpreted as voxel coordinates.
 
-        :returns: a list of values, one per region, which represent
-                  the probability of each region for the specified
-                  location. Returns an empty list if the given
-                  location is out of bounds.
+        :returns: a list of values, one per region.  Returns an empty
+                  list if the given location is out of bounds.
         """
 
         if not voxel:
-            loc = transform.transform([loc], self.worldToVoxMat)[0]
+            loc = affine.transform([loc], self.worldToVoxMat)[0]
             loc = [int(v) for v in loc.round()]
 
         if loc[0] <  0             or \
@@ -812,46 +1044,50 @@ class ProbabilisticAtlas(Atlas):
            loc[2] >= self.shape[2]:
             return []
 
-        return self[loc[0], loc[1], loc[2], :]
+        vals = self[loc[0], loc[1], loc[2], :]
+
+        # We only return labels for this atlas -
+        # the underlying image may have more
+        # volumes than this atlas has labels.
+        return [vals[l.index] for l in self.desc.labels]
 
 
-    def maskProportions(self, mask):
-        """Looks up the probabilities of all regions in the given ``mask``.
+    def maskValues(self, mask):
+        """Looks up the average values of all regions in the given ``mask``.
 
         :arg mask: A 3D :class:`.Image`` which is interpreted as a weighted
                    mask. If the ``mask`` shape does not match that of this
-                   ``ProbabilisticAtlas``, it is resampled using
-                   :meth:`.Image.resample`, with linear interpolation.
+                   ``StatisticAtlas``, it is resampled using
+                   :meth:`Atlas.prepareMask`.
 
-        :returns:  A tuple containing:
-
-                     - A sequence of all labels which are present in the mask
-                     - A sequence containing the proportion, within the mask,
-                       of each present label. The proportions are returned as
-                       values between 0 and 100.
+        :returns:  A sequence containing the average value, within the mask,
+                   of all regions in the atlas.
         """
 
-        labels = []
-        props  = []
-
-        # Make sure that the mask has the same
-        # number of voxels as the atlas image
-        mask      = mask.resample(self.shape[:3], dtype=np.float32, order=0)[0]
+        avgvals   = []
+        mask      = self.prepareMask(mask)
         boolmask  = mask > 0
         weights   = mask[boolmask]
         weightsum = weights.sum()
 
-        for label in range(self.shape[3]):
+        if weightsum == 0:
+            return [0.0] * len(self.desc.labels)
 
-            vals = self[..., label]
-            vals = vals[boolmask] * weights
-            prop = vals.sum() / weightsum
+        for label in self.desc.labels:
 
-            if not np.isclose(prop, 0):
-                labels.append(label)
-                props .append(prop)
+            vals  = self[..., label.index]
+            vals  = vals[boolmask] * weights
+            val   = vals.sum() / weightsum
 
-        return labels, props
+            avgvals.append(val)
+
+        return avgvals
+
+
+class ProbabilisticAtlas(StatisticAtlas):
+    """A 4D atlas which contains one volume for each region. Each volume
+    contains probabiliy values for one region, between 0 and 100.
+    """
 
 
 registry            = AtlasRegistry()
