@@ -7,8 +7,8 @@
 
 import os.path as op
 import            time
+from unittest import mock
 
-import mock
 import pytest
 
 import numpy   as np
